@@ -67,10 +67,10 @@ def send_notifications(email, sender, email_configuration):
     paragraph = email_configuration.get('Email_Content')
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
-
-    email_html = open(file_name).read().format(logo=logo, cover=cover,
-                                               p1=paragraph)
-    BODY_HTML = email_html
+    # email_html = open(file_name)
+    BODY_HTML = open(file_name).read().format(first_header='goodbye',
+                                              p1='World',
+                                              p2='Hello')
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
